@@ -169,6 +169,17 @@ QNetworkRequest QAbstractOAuth2Private::createRequest(QUrl url, const QVariantMa
     return request;
 }
 
+void QAbstractOAuth2Private::prepareRequestImpl(QNetworkRequest *request,
+                                                const QByteArray &verb,
+                                                const QByteArray &body)
+{
+    Q_UNUSED(verb)
+    Q_UNUSED(body)
+    request->setHeader(QNetworkRequest::UserAgentHeader, userAgent);
+    const QString bearer = bearerFormat.arg(token);
+    request->setRawHeader("Authorization", bearer.toUtf8());
+}
+
 /*!
     Constructs a QAbstractOAuth2 object using \a parent as parent.
 */
